==> mall-center-api-0.0.4-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActSkuDataDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/18 18:20.
 */
public class SecKillActSkuDataDto implements Serializable {
    private static final long serialVersionUID = -2999254987400677731L;

    /**
     * 数据id
     */
    private Long id;

    /**
     * 活动id
     */
    private Long actId;

    /**
     * 对应的sku id
     */
    private Long appSkuId;

    /**
     * 秒杀上限
     */
    private Integer secLimit;

    /**
     * 已秒杀数量
     */
    private Integer secCount;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getAppSkuId() {
        return appSkuId;
    }

    public void setAppSkuId(Long appSkuId) {
        this.appSkuId = appSkuId;
    }

    public Integer getSecLimit() {
        return secLimit;
    }

    public void setSecLimit(Integer secLimit) {
        this.secLimit = secLimit;
    }

    public Integer getSecCount() {
        return secCount;
    }

    public void setSecCount(Integer secCount) {
        this.secCount = secCount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> mall-center-api-3.6.14-sources.jar: cn/com/duiba/mall/center/api/domain/dto/seckill/SecKillActSkuDataDto.java <==
package cn.com.duiba.mall.center.api.domain.dto.seckill;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by HePeng on 2019/01/18 18:20.
 */
public class SecKillActSkuDataDto implements Serializable {
    private static final long serialVersionUID = -2999254987400677731L;

    /**
     * 数据id
     */
    private Long id;

    /**
     * 活动id
     */
    private Long actId;

    /**
     * 期次
     */
    private Long phaseNum;

    /**
     * 对应的sku id
     */
    private Long appSkuId;

    /**
     * 秒杀上限
     */
    private Integer secLimit;

    /**
     * 已秒杀数量
     */
    private Integer secCount;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public Long getPhaseNum() {
        return phaseNum;
    }

    public void setPhaseNum(Long phaseNum) {
        this.phaseNum = phaseNum;
    }

    public Long getAppSkuId() {
        return appSkuId;
    }

    public void setAppSkuId(Long appSkuId) {
        this.appSkuId = appSkuId;
    }

    public Integer getSecLimit() {
        return secLimit;
    }

    public void setSecLimit(Integer secLimit) {
        this.secLimit = secLimit;
    }

    public Integer getSecCount() {
        return secCount;
    }

    public void setSecCount(Integer secCount) {
        this.secCount = secCount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
